Index: boot/arch/arm64/src/asm.S
===================================================================
--- boot/arch/arm64/src/asm.S	(revision bc52b5ba1a06b4bd3ca224def5b3861e608da5f5)
+++ boot/arch/arm64/src/asm.S	(revision 99589a9a53db598a3a043217657db813eea50a62)
@@ -33,4 +33,6 @@
 .section BOOTSTRAP
 
+#define DIRECTORY_ENTRIES 16
+
 /* MS-DOS stub */
 msdos_stub:
@@ -51,6 +53,8 @@
 	.long 0                         /* Number of symbols */
 	.short sec_table - opt_header   /* Size of optional header */
-	/* Characteristics = IMAGE_FILE_EXECUTABLE_IMAGE |
-	 *   IMAGE_FILE_LARGE_ADDRESS_AWARE */
+	/*
+	 * Characteristics = IMAGE_FILE_EXECUTABLE_IMAGE |
+	 *   IMAGE_FILE_LARGE_ADDRESS_AWARE
+	 */
 	.short 0x22
 
@@ -87,8 +91,9 @@
 	.quad 0                         /* Size of heap commit */
 	.long 0                         /* Loader flags */
-	.long 0                         /* Number of RVA and sizes */
+	.long DIRECTORY_ENTRIES         /* Number of RVA and sizes */
+	.space DIRECTORY_ENTRIES * 8    /* Directory entries */
 
 sec_table:
-        .ascii ".text\x0\x0\x0"         /* Name */
+	.ascii ".text\x0\x0\x0"         /* Name */
 	.long payload_end - start       /* Virtual size */
 	.long start - msdos_stub        /* Virtual address */
@@ -99,19 +104,21 @@
 	.short 0                        /* Number of relocations */
 	.short 0                        /* Number of line numbers */
-	/* Characteristics = IMAGE_SCN_CNT_CODE | IMAGE_SCN_MEM_EXECUTE |
-	 *   IMAGE_SCN_MEM_READ | IMAGE_SCN_MEM_WRITE */
+	/*
+	 * Characteristics = IMAGE_SCN_CNT_CODE | IMAGE_SCN_MEM_EXECUTE |
+	 *   IMAGE_SCN_MEM_READ | IMAGE_SCN_MEM_WRITE
+	 */
 	.long 0xe0000020
 
+/** Boot loader entry point
+ *
+ * @param x0 UEFI image handle.
+ * @param x1 Pointer to the UEFI system table.
+ *
+ */
 SYMBOL(start)
 	.hidden start
 
 	/*
-	 * Parameters:
-	 * x0 is the image handle.
-	 * x1 is a pointer to the UEFI system table.
-	 */
-
-	/*
-	 * Stay on the UEFI stack. Its size is at least 128 kB, plenty for this
+	 * Stay on the UEFI stack. Its size is at least 128 KiB, plenty for this
 	 * boot loader.
 	 */
